@@ -1,10 +1,5 @@
-context("test-translate-sql-helpers.r")
-
-old <- NULL
-setup(old <<- set_current_con(simulate_dbi()))
-teardown(set_current_con(old))
-
 test_that("aggregation functions warn if na.rm = FALSE", {
+  local_con(simulate_dbi())
   sql_mean <- sql_aggregate("MEAN")
 
   expect_warning(sql_mean("x"), "Missing values")
@@ -12,6 +7,7 @@ test_that("aggregation functions warn if na.rm = FALSE", {
 })
 
 test_that("missing window functions create a warning", {
+  local_con(simulate_dbi())
   sim_scalar <- sql_translator()
   sim_agg <- sql_translator(`+` = sql_infix("+"))
   sim_win <- sql_translator()
@@ -23,6 +19,7 @@ test_that("missing window functions create a warning", {
 })
 
 test_that("missing aggregate functions filled in", {
+  local_con(simulate_dbi())
   sim_scalar <- sql_translator()
   sim_agg <- sql_translator()
   sim_win <- sql_translator(mean = function() {})
@@ -33,19 +30,15 @@ test_that("missing aggregate functions filled in", {
 
 test_that("output of print method for sql_variant is correct", {
   sim_trans <- sql_translator(`+` = sql_infix("+"))
-  expect_known_output(
-    sql_variant(sim_trans, sim_trans, sim_trans),
-    test_path("test-sql-variant.txt"),
-    print = TRUE
-  )
+  expect_snapshot(sql_variant(sim_trans, sim_trans, sim_trans))
 })
 
 test_that("win_rank() is accepted by the sql_translator", {
-  expect_known_output(
-    print(sql_variant(
+  expect_snapshot(
+    sql_variant(
       sql_translator(
         test = win_rank("test")
       )
-    )),
-    test_path("test-sql-translator.txt"))
+    )
+  )
 })
